# Example folder

Contents of this folder is provided on as is terms, whithout support.

* [DigiDocCSharp](./DigiDocCSharp/README.md) - example project to use C# on Windows
* [android](./android/README.md) - example project to use on Android platform
* [ios](./ios/README.md) - example project to use on iOS platform
* [java](./java/README.md) - example project to use with java
* [python](./python/README.md) - example project to use with python
* [pkcs11sign.cpp](pkcs11sign.cpp) - Simple PKCS11Signer example
